@@ -90,41 +90,7 @@ sub read_config {
 						      sparc64
 						      x32
 						 )),
-		  ubuntu_release_names => join(', ', qw(
-							   dapper
-							   edgy
-							   feisty
-							   gutsy
-							   hardy
-							   intrepid
-							   jaunty
-							   karmic
-							   lucid
-							   maverick
-							   natty
-							   oneiric
-							   precise
-							   quantal
-							   raring
-							   saucy
-							   trusty
-							   utopic
-							   vivid
-							   wily
-							   xenial
-							   yakkety
-							   zesty
-							   artful
-							   bionic
-						           cosmic
-							   disco
-							   eoan
-							   focal
-							   groovy
-							   hirsute
-							   impish
-							   jammy
-						      )),
+		  ubuntu_release_names => join(', ', get_ubuntu_names()),
 		  user => $>,
 
 		  # Private
@@ -684,8 +650,8 @@ sub get_upstream_url {
 sub get_original_url {
     my ($filename) = @_;
 
-    # Infer from filename, beware Translation-??_??, assume HTTP
-    $filename =~ s/(?<!Translation-[a-z]{2})_/\//g;
+    # Infer from filename, assume HTTP
+    $filename =~ s/_/\//g;
     return URI->new('http://' . $filename);
 }
 
@@ -894,6 +860,15 @@ sub load_checksum {
     return;
 }
 
+sub get_ubuntu_names {
+    my @names;
+    if (open(my $fh, '<', '/usr/share/distro-info/ubuntu.csv')) {
+	<$fh>; # Skip header
+	push @names, (split /,/)[2] foreach <$fh>;
+    }
+    return @names
+}
+
 ######### HOOKS ###########
 #
 # arg: file to be scanned and added to DB
